# ToolVIPER

Tools and utilities for optimized radio astronomy processing using the VIPER framework.

[![Python 3.11 3.12 3.13](https://img.shields.io/badge/python-3.11%20%7C%203.12%20%7C%203.13-blue)](https://www.python.org/downloads/release/python-3130/)
[![Linux Tests](https://github.com/casangi/toolviper/actions/workflows/python-testing-linux.yml/badge.svg?branch=main)](https://github.com/casangi/toolviper/actions/workflows/python-testing-linux.yml?query=branch%3Amain)
[![macOS Tests](https://github.com/casangi/toolviper/actions/workflows/python-testing-macos.yml/badge.svg?branch=main)](https://github.com/casangi/toolviper/actions/workflows/python-testing-macos.yml?query=branch%3Amain)
[![ipynb Tests](https://github.com/casangi/toolviper/actions/workflows/run-ipynb.yml/badge.svg?branch=main)](https://github.com/casangi/toolviper/actions/workflows/run-ipynb.yml?query=branch%3Amain)
[![Coverage](https://codecov.io/gh/casangi/toolviper/branch/main/graph/badge.svg)](https://codecov.io/gh/casangi/toolviper/branch/main/toolviper)
<!-- [![Documentation Status](https://readthedocs.org/projects/toolviper/badge/?version=latest)](https://toolviper.readthedocs.io) -->
[![Version Status](https://img.shields.io/pypi/v/toolviper.svg)](https://pypi.python.org/pypi/toolviper/)











